==> nextcloud-16.0.5.tgz: nextcloud/apps/privacy/l10n/de.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Datenschutz",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Das Zentrum für Datenschutz zeigt Ihnen, wo Ihre Daten gespeichert werden und wer darauf Zugriff hat. Egal ob Sie Daten freigegeben haben oder es Administratoren sind.",
    "Add external admin" : "Einen externen Administrator hinzufügen",
    "Your files are not protected by encryption." : "Deine Dateien sind nicht mittels Verschlüsselung geschützt.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "Deine Dateien sind mittels der {linkopen}serverseitigen Verschlüsselung ↗{linkclose} verschlüsselt.",
    "This server is protected with full-disk-encryption." : "Dieser Server ist mittels Festplattenverschlüsselung geschützt.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "Deine Dateien sind mittels der {linkopen}serverseitigen Verschlüsselung ↗{linkclose} verschlüsselt. Ausserdem ist deser Server mittels Festplattenverschlüsselung geschützt.",
    "This server is using full-disk-encryption." : "Dieser Server verwendet Festplattenverschlüsselung.",
    "Your data is located in: " : "Deine Daten befinden sich in: ",
    "The admin hasn't selected the location of the server yet." : "Der Administrator hat den Standort des Servers noch nicht ausgewählt.",
    "Please select a country" : "Bitte wähle ein Land",
    "You don't have any shares with individual users." : "Du teilst keine Dateien mit einzelnen Nutzern.",
    "Somaliland" : "Somaliland",
    "United Arab Emirates" : "Vereinigte Arabische Emirate",
    "Afghanistan" : "Afghanistan",
    "Albania" : "Albanien",
    "Armenia" : "Armenien",
    "Angola" : "Angola",
    "Argentina" : "Argentinien",
    "Austria" : "Österreich",
    "Australia" : "Australien",
    "Azerbaijan" : "Aserbaidschan",
    "Bosnia and Herzegowina" : "Bosnien und Herzegowina",
    "Bangladesh" : "Bangladesch",
    "Belgium" : "Belgien",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgarien",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Brunei" : "Brunei",
    "Bolivia" : "Bolivien",
    "Brazil" : "Brasilien",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bhutan",
    "Botswana" : "Botswana",
    "Belarus" : "Weißrussland",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Democratic Republic of the Congo" : "Kongo",
    "Central African Republic" : "Zentralafrikanische Republik",
    "Congo" : "Kongo",
    "Switzerland" : "Schweiz",
    "Cote d'Ivoire" : "Elfenbeinküste",
    "Chile" : "Chile",
    "Cameroon" : "Kamerun",
    "China" : "China",
    "Colombia" : "Kolumbien",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Kuba",
    "Cyprus" : "Zypern",
    "Czech" : "Tschechisch",
    "Germany" : "Deutschland",
    "Djibouti" : "Dschibuti",
    "Denmark" : "Dänemark",
    "Dominican Republic" : "Dominikanische Republik",
    "Algeria" : "Algerien",
    "Ecuador" : "Ekuador",
    "Estonia" : "Estland",
    "Egypt" : "Ägypten",
    "West Sahara" : "Westsahara",
    "Eritrea" : "Eritrea",
    "Spain" : "Spanien",
    "Ethiopia" : "Äthiopien",
    "Finland" : "Finnland",
    "Fiji" : "Fidschi",
    "Falkland Islands" : "Falklandinseln",
    "France" : "Frankreich",
    "Gabon" : "Gabun",
    "United Kingdom" : "Vereinigtes Königreich",
    "Georgia" : "Georgien",
    "Ghana" : "Ghana",
    "Greenland" : "Grönland",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Equatorial Guinea" : "Äquatorialguinea",
    "Greece" : "Griechenland",
    "Guatemala" : "Guatemala",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Honduras" : "Honduras",
    "Croatia" : "Kroatien",
    "Haiti" : "Haiti",
    "Hungary" : "Ungarn",
    "Indonesia" : "Indonesien",
    "Ireland" : "Irland",
    "Israel" : "Israel",
    "India" : "Indien",
    "Iraq" : "Irak",
    "Iran" : "Iran",
    "Iceland" : "Island",
    "Italy" : "Italien",
    "Jamaica" : "Jamaika",
    "Jordan" : "Jordanien",
    "Japan" : "Japan",
    "Kenya" : "Kenia",
    "Kyrgyzstan" : "Kirgistan",
    "Cambodia" : "Kambodscha",
    "North Korea" : "Nordkorea",
    "South Korea" : "Südkorea",
    "Kuwait" : "Kuwait",
    "Kazakhstan" : "Kasachstan",
    "Laos" : "Laos",
    "Lebanon" : "Libanon",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Litauen",
    "Luxembourg" : "Luxemburg",
    "Latvia" : "Lettland",
    "Libya" : "Lybien",
    "Morocco" : "Marokko",
    "Moldova" : "Moldawien",
    "Montenegro" : "Montenegro",
    "Madagascar" : "Madagaskar",
    "Macedonia" : "Mazedonien",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongolei",
    "Mauritania" : "Mauretanien",
    "Malawi" : "Malawi",
    "Mexico" : "Mexiko",
    "Malaysia" : "Malaysia",
    "Mozambique" : "Mosambik",
    "Namibia" : "Namibia",
    "New Caledonia" : "Neukaledonien",
    "Niger" : "Niger",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Niederlande",
    "Norway" : "Norwegen",
    "Nepal" : "Nepal",
    "New Zealand" : "Neuseeland",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "Papua New Guinea" : "Papua-Neuguinea",
    "Philippines" : "Philippinen",
    "Pakistan" : "Pakistan",
    "Poland" : "Polen",
    "Puerto Rico" : "Puerto Rico",
    "Portugal" : "Portugal",
    "Paraguay" : "Paraguay",
    "Qatar" : "Katar",
    "Romania" : "Rumänien",
    "Serbia" : "Serbien",
    "Russia" : "Russland",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Saudiarabien",
    "Solomon Islands" : "Salomonen",
    "Sudan" : "Sudan",
    "Sweden" : "Schweden",
    "Singapore" : "Singapur",
    "Slovenia" : "Slowenien",
    "Slovakia" : "Slowakei",
    "Sierra Leone" : "Sierra Leone",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Surinam",
    "South Sudan" : "Südsudan",
    "El Salvador" : "El Salvador",
    "Syria" : "Syrien",
    "Swaziland" : "Swasiland",
    "Chad" : "Tschad",
    "Fr. S. Antarctic Lands" : "Französische Süd- und Antarktisgebiete",
    "Togo" : "Togo",
    "Thailand" : "Thailand",
    "Tajikistan" : "Tadschikistan",
    "Timor-Leste" : "Osttimor",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunesien",
    "Turkey" : "Türkei",
    "Trinidad and Tobago" : "Trinidad und Tobago",
    "Taiwan" : "Taiwan",
    "Tanzania" : "Tansania",
    "Ukraine" : "Ukraine",
    "Uganda" : "Uganda",
    "United States" : "Vereinigte Staaten von Amerika",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Usbekistan",
    "Venezuela" : "Venezuela",
    "Vietnam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Yemen" : "Jemen",
    "South Africa" : "Südafrika",
    "Zambia" : "Sambia",
    "Zimbabwe" : "Simbabwe",
    "Your Nextcloud account" : "Dein Nextcloud Konto",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Deine Daten repräsentieren, wer Du bist und können leicht missbraucht werden. Wir von Nextcloud glauben, dass Du das Recht hast zu entscheiden, was mit Deinen Daten geschieht. Nextcloud schützt Deine Rechte gemäß dem Benutzerdatenmanifest!",
    "User Data Manifesto 2.0" : "Benutzer-Daten-Manifest 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "Definition von Grundrechten für Menschen zur Kontrolle ihrer eigenen Daten im Internetzeitalter",
    "Control" : "Kontrolle",
    "over user data access" : "über den Zugriff auf Benutzerdaten",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Daten, die explizit und bereitwillig von einem Benutzer hochgeladen werden, sollten unter der endgültigen Kontrolle des Benutzers stehen. Die Benutzer sollten entscheiden können, wer direkten Zugriff auf ihre Daten gewährt und mit welchen Berechtigungen und Lizenzen dieser Zugriff gewährt werden soll.",
    "Knowledge" : "Wissenswertes",
    "of how the data is stored" : "wie die Daten gespeichert werden",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Wenn die Daten zu einem bestimmten Dienstanbieter hochgeladen werden, sollten die Benutzer darüber informiert werden, wo dieser bestimmte Dienstanbieter die Daten speichert, wie lange, in welcher Rechtsordnung der jeweilige Dienstanbieter tätig ist und welche Gesetze gelten.",
    "Freedom" : "Freiheit",
    "to choose a platform" : "eine Plattform zu wählen",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Benutzer sollten jederzeit in der Lage sein, ihre Daten aus dem Dienst zu extrahieren, ohne dass es zu einer Herstellerbindung kommt. Um dies zu gewährleisten, sind offene Standards für Formate und Protokolle notwendig.",
    "Learn more ↗" : "Erfahre mehr ↗",
    "Where is your data?" : "Wo befinden sich Deine Daten?",
    "Who has access to your data?" : "Wer hat Zugriff auf Deine Daten?",
    "Administrators" : "Administratoren",
    "People you shared with" : "Menschen, mit denen Du geteilt hast",
    "Privacy policy" : "Datenschutz",
    "Read the privacy policy." : "Lese hier die Datenschutzerklärung.",
    "Encryption" : "Verschlüsselung"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-18.0.4.tgz: nextcloud/apps/privacy/l10n/de.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Datenschutz",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Das Zentrum für Datenschutz zeigt Ihnen, wo Ihre Daten gespeichert werden und wer darauf Zugriff hat. Egal ob Sie Daten freigegeben haben oder es Administratoren sind.",
    "Remove external admin" : "Externen Administrator entfernen",
    "Add external admin" : "Einen externen Administrator hinzufügen",
    "Your files are not protected by encryption." : "Deine Dateien sind nicht mittels Verschlüsselung geschützt.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "Deine Dateien sind mittels der {linkopen}serverseitigen Verschlüsselung ↗{linkclose} verschlüsselt.",
    "This server is protected with full-disk-encryption." : "Dieser Server ist mittels Festplattenverschlüsselung geschützt.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "Deine Dateien sind mittels der {linkopen}serverseitigen Verschlüsselung ↗{linkclose} verschlüsselt. Ausserdem ist deser Server mittels Festplattenverschlüsselung geschützt.",
    "This server is using full-disk-encryption." : "Dieser Server verwendet Festplattenverschlüsselung.",
    "Change data location" : "Datenspeicherort ändern",
    "Your data is located in: " : "Deine Daten befinden sich in: ",
    "The admin hasn't selected the location of the server yet." : "Der Administrator hat den Standort des Servers noch nicht ausgewählt.",
    "Please select a country" : "Bitte wähle ein Land",
    "You don't have any shares with individual users." : "Du teilst keine Dateien mit einzelnen Nutzern.",
    "Somaliland" : "Somaliland",
    "United Arab Emirates" : "Vereinigte Arabische Emirate",
    "Afghanistan" : "Afghanistan",
    "Albania" : "Albanien",
    "Armenia" : "Armenien",
    "Angola" : "Angola",
    "Argentina" : "Argentinien",
    "Austria" : "Österreich",
    "Australia" : "Australien",
    "Azerbaijan" : "Aserbaidschan",
    "Bosnia and Herzegowina" : "Bosnien und Herzegowina",
    "Bangladesh" : "Bangladesch",
    "Belgium" : "Belgien",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgarien",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Brunei" : "Brunei",
    "Bolivia" : "Bolivien",
    "Brazil" : "Brasilien",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bhutan",
    "Botswana" : "Botswana",
    "Belarus" : "Weißrussland",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Democratic Republic of the Congo" : "Kongo",
    "Central African Republic" : "Zentralafrikanische Republik",
    "Congo" : "Kongo",
    "Switzerland" : "Schweiz",
    "Cote d'Ivoire" : "Elfenbeinküste",
    "Chile" : "Chile",
    "Cameroon" : "Kamerun",
    "China" : "China",
    "Colombia" : "Kolumbien",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Kuba",
    "Cyprus" : "Zypern",
    "Czech" : "Tschechisch",
    "Germany" : "Deutschland",
    "Djibouti" : "Dschibuti",
    "Denmark" : "Dänemark",
    "Dominican Republic" : "Dominikanische Republik",
    "Algeria" : "Algerien",
    "Ecuador" : "Ekuador",
    "Estonia" : "Estland",
    "Egypt" : "Ägypten",
    "West Sahara" : "Westsahara",
    "Eritrea" : "Eritrea",
    "Spain" : "Spanien",
    "Ethiopia" : "Äthiopien",
    "Finland" : "Finnland",
    "Fiji" : "Fidschi",
    "Falkland Islands" : "Falklandinseln",
    "France" : "Frankreich",
    "Gabon" : "Gabun",
    "United Kingdom" : "Vereinigtes Königreich",
    "Georgia" : "Georgien",
    "Ghana" : "Ghana",
    "Greenland" : "Grönland",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Equatorial Guinea" : "Äquatorialguinea",
    "Greece" : "Griechenland",
    "Guatemala" : "Guatemala",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Honduras" : "Honduras",
    "Croatia" : "Kroatien",
    "Haiti" : "Haiti",
    "Hungary" : "Ungarn",
    "Indonesia" : "Indonesien",
    "Ireland" : "Irland",
    "Israel" : "Israel",
    "India" : "Indien",
    "Iraq" : "Irak",
    "Iran" : "Iran",
    "Iceland" : "Island",
    "Italy" : "Italien",
    "Jamaica" : "Jamaika",
    "Jordan" : "Jordanien",
    "Japan" : "Japan",
    "Kenya" : "Kenia",
    "Kyrgyzstan" : "Kirgistan",
    "Cambodia" : "Kambodscha",
    "North Korea" : "Nordkorea",
    "South Korea" : "Südkorea",
    "Kuwait" : "Kuwait",
    "Kazakhstan" : "Kasachstan",
    "Laos" : "Laos",
    "Lebanon" : "Libanon",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Litauen",
    "Luxembourg" : "Luxemburg",
    "Latvia" : "Lettland",
    "Libya" : "Lybien",
    "Morocco" : "Marokko",
    "Moldova" : "Moldawien",
    "Montenegro" : "Montenegro",
    "Madagascar" : "Madagaskar",
    "Macedonia" : "Mazedonien",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongolei",
    "Mauritania" : "Mauretanien",
    "Malawi" : "Malawi",
    "Mexico" : "Mexiko",
    "Malaysia" : "Malaysia",
    "Mozambique" : "Mosambik",
    "Namibia" : "Namibia",
    "New Caledonia" : "Neukaledonien",
    "Niger" : "Niger",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Niederlande",
    "Norway" : "Norwegen",
    "Nepal" : "Nepal",
    "New Zealand" : "Neuseeland",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "Papua New Guinea" : "Papua-Neuguinea",
    "Philippines" : "Philippinen",
    "Pakistan" : "Pakistan",
    "Poland" : "Polen",
    "Puerto Rico" : "Puerto Rico",
    "Portugal" : "Portugal",
    "Paraguay" : "Paraguay",
    "Qatar" : "Katar",
    "Romania" : "Rumänien",
    "Serbia" : "Serbien",
    "Russia" : "Russland",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Saudiarabien",
    "Solomon Islands" : "Salomonen",
    "Sudan" : "Sudan",
    "Sweden" : "Schweden",
    "Singapore" : "Singapur",
    "Slovenia" : "Slowenien",
    "Slovakia" : "Slowakei",
    "Sierra Leone" : "Sierra Leone",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Surinam",
    "South Sudan" : "Südsudan",
    "El Salvador" : "El Salvador",
    "Syria" : "Syrien",
    "Swaziland" : "Swasiland",
    "Chad" : "Tschad",
    "Fr. S. Antarctic Lands" : "Französische Süd- und Antarktisgebiete",
    "Togo" : "Togo",
    "Thailand" : "Thailand",
    "Tajikistan" : "Tadschikistan",
    "Timor-Leste" : "Osttimor",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunesien",
    "Turkey" : "Türkei",
    "Trinidad and Tobago" : "Trinidad und Tobago",
    "Taiwan" : "Taiwan",
    "Tanzania" : "Tansania",
    "Ukraine" : "Ukraine",
    "Uganda" : "Uganda",
    "United States" : "Vereinigte Staaten von Amerika",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Usbekistan",
    "Venezuela" : "Venezuela",
    "Vietnam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Yemen" : "Jemen",
    "South Africa" : "Südafrika",
    "Zambia" : "Sambia",
    "Zimbabwe" : "Simbabwe",
    "Your Nextcloud account" : "Dein Nextcloud Konto",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Deine Daten repräsentieren, wer Du bist und können leicht missbraucht werden. Wir von Nextcloud glauben, dass Du das Recht hast zu entscheiden, was mit Deinen Daten geschieht. Nextcloud schützt Deine Rechte gemäß dem Benutzerdatenmanifest!",
    "User Data Manifesto 2.0" : "Benutzer-Daten-Manifest 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "Definition von Grundrechten für Menschen zur Kontrolle ihrer eigenen Daten im Internetzeitalter",
    "Control" : "Kontrolle",
    "over user data access" : "über den Zugriff auf Benutzerdaten",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Daten, die explizit und bereitwillig von einem Benutzer hochgeladen werden, sollten unter der endgültigen Kontrolle des Benutzers stehen. Die Benutzer sollten entscheiden können, wer direkten Zugriff auf ihre Daten gewährt und mit welchen Berechtigungen und Lizenzen dieser Zugriff gewährt werden soll.",
    "Knowledge" : "Wissenswertes",
    "of how the data is stored" : "wie die Daten gespeichert werden",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Wenn die Daten zu einem bestimmten Dienstanbieter hochgeladen werden, sollten die Benutzer darüber informiert werden, wo dieser bestimmte Dienstanbieter die Daten speichert, wie lange, in welcher Rechtsordnung der jeweilige Dienstanbieter tätig ist und welche Gesetze gelten.",
    "Freedom" : "Freiheit",
    "to choose a platform" : "eine Plattform zu wählen",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Benutzer sollten jederzeit in der Lage sein, ihre Daten aus dem Dienst zu extrahieren, ohne dass es zu einer Herstellerbindung kommt. Um dies zu gewährleisten, sind offene Standards für Formate und Protokolle notwendig.",
    "Learn more ↗" : "Erfahre mehr ↗",
    "Where is your data?" : "Wo befinden sich Deine Daten?",
    "Who has access to your data?" : "Wer hat Zugriff auf Deine Daten?",
    "Administrators" : "Administratoren",
    "People you shared with" : "Menschen, mit denen Du geteilt hast",
    "Privacy policy" : "Datenschutz",
    "Read the privacy policy." : "Lese hier die Datenschutzerklärung.",
    "Encryption" : "Verschlüsselung"
},
"nplurals=2; plural=(n != 1);");
